@@ -9,7 +9,7 @@ embed.perm <- function(x1, x2, B = 999) {
   Rbi <- sqrt( Rfast::rowsums(S^2) ) ## the mean resultant length of each group
   S <- Rfast::colmeans(x)
   Rbar <- sqrt( sum(S^2) )  ## the mean resultant length based on all the data
-  Ft <- (n - 2) * ( sum(ni * Rbi^2) - n * Rbar^2) / ( n - sum(ni * Rbi^2) ) 
+  Ft <- (n - 2) * ( sum(ni * Rbi^2) - n * Rbar^2) / ( n - sum(ni * Rbi^2) )
 
   pft <- numeric(B)
   for (i in 1:B) {
@@ -19,8 +19,14 @@ embed.perm <- function(x1, x2, B = 999) {
     pft[i] <- (n - 2) * ( sum(ni * Rbi^2) - n * Rbar^2) / ( n - sum(ni * Rbi^2) )
   }
 
-  pvalue <- ( sum(pft > Ft) + 1 ) / (B + 1)
-  res <- c(Ft, pvalue)
-  names(res) <- c("test", "p-value")
-  res
+  p.value <- ( sum(pft > Ft) + 1 ) / (B + 1)
+  statistic <- Ft  ;   names(statistic) <- "Embedding test statistic"
+  parameter <- "NA"     ;   names(parameter) <- "df"
+  alternative <- "The 2 directional mean vectors differ"
+  method <- "Permutation ANOVA for 2 directional mean vectors using the embedding approach"
+  data.name <- c("data ", " groups")
+  result <- list( statistic = statistic, parameter = parameter, p.value = p.value,
+                  alternative = alternative, method = method, data.name = data.name )
+  class(result) <- "htest"
+  return(result)
 }
