@@ -11,19 +11,18 @@ vmkde.tune <- function(u, low = 0.1, up = 1, rads = TRUE) {
   if ( !rads )  u <- u/180 * pi
   x <- cbind( cos(u), sin(u) )
   disa <- tcrossprod(x)
-  diag(disa) <- 1
   expa <- exp(disa)
-  diag(expa) <- NA  ## we do not want the diagonal elements
+  diag(expa) <-  - Inf  ## we do not want the diagonal elements
   con <- 2 * (n - 1) * pi
 
-   funa <- function(h) {
-    A <- expa^( 1 / h^2 )
-    f <- rowSums( A, na.rm = TRUE ) / con / besselI(1/h^2, 0)
-    sum( log(f) )
-   }
+  funa <- function(h) {
+    A <- expa^h
+    f <- rowSums( A )
+    sum( log(f) ) - n * log( besselI(h, 0) )
+  }
 
   bar <- optimize(funa, c(low, up), maximum = TRUE)
-  res <- c( bar$maximum, bar$objective/n )
+  res <- c( bar$maximum, bar$objective/n - log(con) )
   names(res) <- c("Optimal h", "cv")
   res
 }
